"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.gitTask = void 0;

var _toolLib = require("@kettil/tool-lib");

var _add = require("../actions/git/add");

var _ls = require("../actions/git/ls");

var _staged = require("../actions/git/staged");

var _commitlint = require("../actions/tools/commitlint");

var _existFiles = require("../cmd/existFiles");

var _cleanAnalyseFiles = require("../utils/cleanAnalyseFiles");

var _taskHook = require("../utils/taskHook");

var _analyseTask = require("./analyseTask");

var _depsTask = require("./depsTask");

var _licenseTask = require("./licenseTask");

var _testTask = require("./testTask");

const gitTask = async (argv, {
  edit
}) => {
  await (0, _taskHook.taskHook)(argv, {
    task: 'git',
    type: 'pre'
  });

  if (!(0, _toolLib.isString)(edit) || edit.trim() === '') {
    throw new Error('Argument "edit" is required');
  }

  await (0, _commitlint.commitlintAction)(argv, {
    edit
  });
  const stagedFiles = await (0, _staged.gitStagedAction)(argv, {});

  if (stagedFiles.length > 0) {
    const files = await (0, _existFiles.existFiles)(stagedFiles, argv.cwd);
    const {
      eslintFiles,
      mergedFiles,
      prettierFiles
    } = (0, _cleanAnalyseFiles.cleanAnalyseFiles)(files);
    const unstagedFiles = await (0, _ls.gitLsAction)(argv, {
      mode: 'all'
    });
    const intersectFiles = mergedFiles.filter(file => unstagedFiles.includes(file));

    if (intersectFiles.length > 0) {
      const changedFiles = intersectFiles.map(file => `       ▸ ${file}\n`).join('');
      throw new Error(`The following files were changed after adding:\n${changedFiles}`);
    }

    await (0, _analyseTask.analyseTask)({ ...argv,
      ci: false
    }, {
      files: {
        eslintFiles,
        prettierFiles
      }
    });
    await (0, _add.gitAddAction)(argv, {
      files
    });
    await (0, _testTask.testTask)({ ...argv,
      ci: true
    }, {});
    await (0, _licenseTask.licenseTask)(argv, {});
    await (0, _depsTask.depsTask)(argv, {});
  }

  await (0, _taskHook.taskHook)(argv, {
    task: 'git',
    type: 'post'
  });
};

exports.gitTask = gitTask;